/*
 * $Id: sgtk-util.c,v 1.14 2004/03/11 17:55:04 jylefort Exp $
 *
 * Copyright (c) 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <gtk/gtk.h>
#include "gettext.h"

/*** function declarations ***************************************************/

static void sgtk_widget_activate_h (GtkWidget *widget, gpointer data);

/*** implementation **********************************************************/

void
sgtk_flush (void)
{
  while (gtk_events_pending())
    gtk_main_iteration();
}

char *
sgtk_translate_func (const char *path, gpointer data)
{
  return _(path);
}

GdkPixbuf *
sgtk_pixbuf_scale (GdkPixbuf *pixbuf, GtkIconSize size)
{
  int width;
  int height;
  gboolean status;

  g_return_val_if_fail(pixbuf != NULL, NULL);

  status = gtk_icon_size_lookup(size, &width, &height);
  g_return_val_if_fail(status == TRUE, NULL);

  return gdk_pixbuf_scale_simple(pixbuf, width, height, GDK_INTERP_BILINEAR);
}

void
sgtk_widget_set_next_widget (GtkWidget *widget, GtkWidget *next)
{
  g_return_if_fail(GTK_IS_WIDGET(widget));
  g_return_if_fail(GTK_IS_WIDGET(next));

  g_object_set_data(G_OBJECT(widget), "focus-next", next);
  g_signal_connect(G_OBJECT(widget), "activate",
		   G_CALLBACK(sgtk_widget_activate_h), next);
}

static void
sgtk_widget_activate_h (GtkWidget *widget, gpointer data)
{
  GtkWidget *next = data;

  while (! GTK_WIDGET_IS_SENSITIVE(next))
    {
      next = g_object_get_data(G_OBJECT(next), "focus-next");
      g_return_if_fail(next != NULL);
    }

  gtk_widget_grab_focus(next);
}
